<div align="center">

# Ichika


[![PyPI](https://img.shields.io/pypi/v/ichika)](https://pypi.org/project/ichika)
[![Python Version](https://img.shields.io/pypi/pyversions/ichika)](https://pypi.org/project/ichika)
[![License](https://img.shields.io/github/license/BlueGlassBlock/Ichika)](https://github.com/BlueGlassBlock/Ichika/blob/master/LICENSE)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)

</div>

## 鸣谢

- [AWR](https://github.com/wybxc/awr): Ichika 的前身和部分代码来源
- [ricq](https://github.com/lz1998/ricq): 使用 Rust 实现的高性能 QQ 协议 移植于 [OICQ](https://github.com/takayama-lily/oicq)
- [mirai](https://github.com/mamoe/mirai): 高效率 QQ 机器人支持库
- [PyO3](https://github.com/PyO3/PyO3): Python 解释器的 Rust 绑定
- [GraiaProject](https://github.com/GraiaProject): 用于 Bot 开发的一系列高效, 现代化, 充分可扩展的工具链

## 许可证

`Ichika` 使用 [`GNU AGPL-3.0`](https://choosealicense.com/licenses/agpl-3.0/) 作为许可证，这意味着你需要遵守相应的规则。